@@ -2,6 +2,6 @@
 #![deny(missing_debug_implementations)]
 #![doc = include_str!("../Readme.md")]
 
-pub use crate::traits::Projective;
+pub use crate::traits::{Projective, Projective3D};
 
 mod traits;
